summaryrefslogtreecommitdiffstats
path: root/parts/filecreate/filecreate_listitem.h
diff options
context:
space:
mode:
Diffstat (limited to 'parts/filecreate/filecreate_listitem.h')
-rw-r--r--parts/filecreate/filecreate_listitem.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/parts/filecreate/filecreate_listitem.h b/parts/filecreate/filecreate_listitem.h
index 3b2702d3..41651850 100644
--- a/parts/filecreate/filecreate_listitem.h
+++ b/parts/filecreate/filecreate_listitem.h
@@ -1,7 +1,7 @@
/***************************************************************************
* Copyright (C) 2003 by Julian Rockey *
* linux@jrockey.com *
* thanks: Roberto Raggi for QSimpleRichText stuff *
* *
* This program is free software; you can redistribute it and/or modify *
* it under the terms of the GNU General Public License as published by *
@@ -13,7 +13,7 @@
#define __FILECREATE_LISTITEM_H__
#include <klistview.h>
-#include <qobject.h>
+#include <tqobject.h>
#include "filecreate_filetype.h"
@@ -24,7 +24,7 @@ namespace FileCreate {
class ListItem : public KListViewItem {
public:
- ListItem(QListView *listview, const FileType *filetype);
+ ListItem(TQListView *listview, const FileType *filetype);
ListItem(ListItem *listitem, const FileType *filetype);
virtual ~ListItem();
@@ -32,14 +32,14 @@ public:
virtual void setup();
virtual void setHeight( int height );
- virtual void paintCell( QPainter* p, const QColorGroup& gc, int column, int width, int align );
+ virtual void paintCell( TQPainter* p, const TQColorGroup& gc, int column, int width, int align );
virtual void prepareResize();
private:
const FileType *m_filetype;
int m_iconHeight;
void init();
- QSimpleRichText *m_filetypeRenderer;
+ TQSimpleRichText *m_filetypeRenderer;
};
@@ -1,7 +1,7 @@
* Copyright (C) 2003 by Julian Rockey *
* linux@jrockey.com *
- * thanks: Roberto Raggi for QSimpleRichText stuff *
+ * thanks: Roberto Raggi for TQSimpleRichText stuff *
* *
* This program is free software; you can redistribute it and/or modify *